==> pypros-0.0.9.tar.gz: pypros-0.0.9/README.md <==
[![PyPI](https://img.shields.io/pypi/v/pypros.svg)](https://pypi.org/project/pypros/)
[![Anaconda-Server Badge](https://anaconda.org/meteocat/pypros/badges/version.svg)](https://anaconda.org/meteocat/pypros)
[![Documentation Status](https://readthedocs.org/projects/pypros/badge/?version=latest)](https://pypros.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/meteocat/pypros.svg?branch=master)](https://travis-ci.org/meteocat/pypros)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/meteocat/pypros-examples/master)


[![Logo](https://github.com/meteocat/pypros/blob/master/docs/source/_static/logo_pros_small.png)](#)


PyPROS, precipitation type calculation: rain or snow
===================================

The PyPROS package applies several algorithms to estimate the precipitation type and discriminate it among rain, sleet and snow. 

Given an air temperature and dew point temperature fields a precipitation type field can be obtained. In addition, if a reflectivity field is supplied, the precipitation area is masked.

Installation
============

To install pyPROS you can have a look at [pyPROS installation](https://pypros.readthedocs.io/en/latest/installation.html) documentation.

Use
===
Different precipitation type discrimination strategies are implemented in this package. More information in [pyPROS documentation](https://pypros.readthedocs.io/en/latest/index.html)

A set of examples were designed to explore the different possibilities of PROS.

Another repository was created to store sample data and the examples in jupyter notebooks [pypros-examples](https://github.com/meteocat/pypros-examples)

==> pypros-0.0.12.tar.gz: pypros-0.0.12/README.md <==
[![PyPI](https://img.shields.io/pypi/v/pypros.svg)](https://pypi.org/project/pypros/)
[![Anaconda-Server Badge](https://anaconda.org/meteocat/pypros/badges/version.svg)](https://anaconda.org/meteocat/pypros)
[![Documentation Status](https://readthedocs.org/projects/pypros/badge/?version=latest)](https://pypros.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/meteocat/pypros.svg?branch=master)](https://travis-ci.org/meteocat/pypros)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/meteocat/pypros-examples/master)


[![Logo](https://github.com/meteocat/pypros/blob/master/docs/source/_static/logo_pros_small.png)](#)


PyPROS, precipitation type calculation: rain or snow
====================================================

The PyPROS package applies several algorithms to estimate the precipitation type and discriminate it among rain, sleet and snow. 

Given an air temperature and dew point temperature fields a precipitation type field can be obtained. In addition, if a reflectivity field is supplied, the precipitation area is masked.

Installation
============

To install pyPROS you can have a look at [pyPROS installation](https://pypros.readthedocs.io/en/latest/installation.html) documentation.

Use
===
Different precipitation type discrimination schemes are implemented in this package. More information in [pyPROS documentation](https://pypros.readthedocs.io/en/latest/index.html)

A set of examples were designed to explore the different possibilities of PROS.

Another repository was created to store sample data and the examples in jupyter notebooks [pypros-examples](https://github.com/meteocat/pypros-examples)
